@@ -60,7 +60,3 @@ SOURCE_DB = os.environ.get("SOURCE_DB", "mimic")
 SOURCE_USER = os.environ.get("SOURCE_USER", "mimic")
 SOURCE_PASSWORD = os.environ.get("SOURCE_PASSWORD", "mimic")
 SOURCE_TYPE = os.environ.get("SOURCE_TYPE", "postgres")
-
-# FDW
-
-CREATE_FDW_TEMPLATE = "create_fdw.sql.j2"
